#include "SlideShowWin.h"
#include <iostream.h>
#include <qmessagebox.h>
#include <qcolor.h>
#include <qstatusbar.h>
#include <stdlib.h>
#include <qpixmap.h>
#include <qprogressdialog.h>
#include <qapplication.h>
#include <qevent.h>

SlideShowWin::SlideShowWin(int n,QString **files,QString dir)
{
	setCaption(dir);

	setPaletteBackgroundColor(Qt::white);
	
	statusBar()->hide();
	
	showFullScreen();
	full_screen = 1;
	
	image_textlabel->setAutoResize(TRUE);

	num_files = n;
	
	filenames = files;		
	
	pages = (QPixmap **)malloc(sizeof(QPixmap *)*n);
	if(pages == NULL)
	{
		cerr<<"pages is null\n";
	}
	
	int i;
	
//	cerr<<"loading ... ";
	
	QProgressDialog progress( "Loading Slides...", "Quit",n,
                          this, "progress", TRUE );
	
	for(i=0;i<n;i++)
	{
//		cout <<*files[i]<<"\n";
//		cerr <<i+1<<" ";
		qApp->processEvents();
		progress.setProgress(i);
		qApp->processEvents();
		
		QPixmap *pixmap = new QPixmap(*filenames[i]);
		if(pixmap->isNull())
		{
//			cerr<<*filenames[i]<<"  not found/Bad image\n";
			QString nf(" Not Found");
			QMessageBox win( "Slide Show",
        			*filenames[i]+nf,
        			QMessageBox::Warning,
        			QMessageBox::Ok ,
        			0,
        			0);
			exit(-1);
		}
		qApp->processEvents();
		
		pages[i] = pixmap;
		qApp->processEvents();
		if ( progress.wasCancelled() )
		{
			exit(-1);
		}
	}
	
//	cerr<<" done \n";
	
	current_file = 0;
	
	nextImage();

}

SlideShowWin::~SlideShowWin()
{



}

void SlideShowWin::showEvent ( QShowEvent * )
{
}

void SlideShowWin::mousePressEvent ( QMouseEvent * e ) 
{
//	cerr<<"click\n";
	if(! full_screen )
	{
		showFullScreen();
		full_screen = 1;
		return;
	}
	
	if(e->button() == QMouseEvent::LeftButton )
	{
		nextImage();
	}
	
	if(e->button() == QMouseEvent::RightButton )
	{
		current_file = current_file - 2;
		if(current_file < 0) 
		{
			qApp->beep();
			current_file = 0;
		}
		nextImage();
	}
	
}

void SlideShowWin::keyPressEvent ( QKeyEvent * e ) 
{
	QString key;
	
	key = e->text();
	
	if(key.ref(0) == 'Q' || key.ref(0) == 'q')
	{
		QMessageBox win( "Slide Show",
        			"Really Quit?",
        			QMessageBox::Information,
        			QMessageBox::Yes ,
        			QMessageBox::No| QMessageBox::Default | QMessageBox::Escape,
        			0);
		
	
		if(win.exec() == QMessageBox::Yes)
		{
			emit quit();
		}
		return;
	}
	
	if(key.ref(0) == '1' )
	{
		current_file = 0;
		nextImage();
	}
	if(key.ref(0) == '0' )
	{
		current_file = num_files-1;
		nextImage();
	}
	if(key.ref(0) == 'b' || key.ref(0) == 'B' 
		|| e->key() == Qt::Key_Up || e->key() == Qt::Key_Prior)
	{
		current_file --;
		current_file --;
		if(current_file < 0) 
		{
			qApp->beep();
			current_file = 0;
		}
		nextImage();
	}	
	if(key.ref(0) == 'n' || key.ref(0) == 'N' || e->key() == Qt::Key_Space 
		|| e->key() == Qt::Key_Down || e->key() == Qt::Key_Next)
	{
		nextImage();
	}
	if(key.ref(0) == 'h' || key.ref(0) == 'H')
	{
		showNormal();
		showMinimized();
		full_screen = 0;
	}
	if(key.ref(0) == 'f' || key.ref(0) == 'F')
	{
		showFullScreen();
		full_screen = 1;
	}
}

void SlideShowWin::nextImage()
{
	if(current_file > -1 && current_file < num_files)
	{
/*
		QPixmap pixmap(*filenames[current_file]);
		
		if(pixmap.isNull())					
		{
			QString file(*filenames[current_file]);
		
			QMessageBox win( "Not Found",
        			file,
        			QMessageBox::Information,
        			QMessageBox::Yes ,
        			QMessageBox::No| QMessageBox::Default | QMessageBox::Escape,
        			0);
				
			win.exec();
			return;
		}
	
		setFixedSize(pixmap.width(),pixmap.height());

		image_textlabel->setPixmap(pixmap);
*/
//		setFixedSize(pages[current_file]->width(),pages[current_file]->height());
			
		image_textlabel->move((width()-pages[current_file]->width())/2,
			(height()-pages[current_file]->height())/2);
	
		image_textlabel->setPixmap(*pages[current_file]);
		
		current_file ++;
	}
	else
	{
		qApp->beep();
	}

}
